%This is a script used to segment ImageField6 with the active mask
%algorithm to reproduce results reported in Table 1.
%
%       This file is part of the Matlab code provided for the following
%       reproducible paper:
%
%       Gowri Srinivasa, Matthew C. Fickus, Yusong Guo, Adam D. Linstedt, Jelena Kovacevic,
%       "Active mask segmentation of fluorescence microscope cell images",
%       IEEE Transactions on Image Processing. May 2008. Submitted.
%
%       This program is free software; you can redistribute it and/or modify it
%       under the terms of the GNU General Public License as published by the
%       Free Software Foundation; either version 2 of the License, or (at your
%       option) any later version. This software is distributed in the hope that
%       it will be useful, but without any warranty; without even the implied
%       warranty of merchantability or fitness for a particular purpose.
%       See the GNU General Public License for more details
%       (enclosed in the file COPYING).
%
%       GNU General Public License,
%       Copyright (C) 2008,
%       bimagicLab, Center for Bioimage Informatics (CBI)
%       Carnegie Mellon University,
%       Pittsburgh, PA 15213, USA.
%
% COMMENTS
%
%       Authors: Justin Newberg and Gowri Srinivasa
%       Latest modifications: April 22, 2008.
%       This script works only in MATLAB 2007a and above
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initialization - Replace stack number and change path for each image field
stackNo=6;
load SW_Seeds_6.mat;
path = ('C:\08_SrinivasaFYLK_OriginalImages\ImageField6\');
filenamebase=sprintf('SW_Mask_%d',stackNo);

for imNo=2:20
    if imNo<=9
        cell=imread(strcat(path,'\YSG2-21_T0002_WavelengthA_Z000',num2str(imNo),'.tif'));
    else
        cell=imread(strcat(path,'\YSG2-21_T0002_WavelengthA_Z00',num2str(imNo),'.tif'));
    end

    for i=1:2
        cell=uint8(ComputeBlur(double(cell)));
    end

    [MM,NN]=size(cell);
    XX=zeros(MM,NN);
    for m=1:MM/2-1
        XX(m+1,:)=m;
        XX(MM-m+1,:)=-m;
    end
    YY=zeros(MM,NN);
    for n=1:NN/2-1;
        YY(:,n+1)=n;
        YY(:,NN-n+1)=-n;
    end

    S=0.5*ones(MM,NN);
    V=double(cell);
    V = V-min(min(V));
    V = V/(max(max(V)));
    alpha = 0.5;
    beta = 0.9;
    V = (beta-alpha)*V+alpha;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    fgseeds=SW_Seeds;
    mi = min(cell(:)); %background seeds
    seeds = 255*uint8(fgseeds) + uint8(cell==mi);

    regionSW = seededwatershed(255-cell, seeds);
    R=bwlabeln(regionSW,4);
    if (min(min(R))==1)
        I = hsv2rgb(mod((R-1)/length(unique(R))+2/3,1),S,V); %Scale the coarse images to equal the size of the detail image requested, so all the results are the same size
    else
        I = hsv2rgb(mod(R/length(unique(R))+2/3,1),S,V); %Scale the coarse images to equal the size of the detail image requested, so all the results are the same size
    end
    imwrite(I,sprintf('SW_%d_%d.png',stackNo,imNo));
    fName=strcat('SW_Mask_',num2str(imNo),'.mat');
    save(strcat('SW_Mask_',num2str(imNo),'.mat'));
end