% This function calls the watershed routine using both foreground and
% background seeds to limit the growth of watershed regions
%
% Author - Justin Newberg
% Last modified - April 17, 2008.
%
% Copyright (C) 2006  Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

function regions = seededwatershed( cell, seeds)

N = numel( size(cell));
M = numel( size(seeds));

switch N
    case 2
        conn = 4;
    case 3
        conn = 6;
    otherwise
        error( 'Improper image dimensions');
end

if N~=M
    error( 'Inputs do not have matching dimensions.');
end

% Perform watershed
W = watershed_meyer(cell,conn,bwlabeln( seeds>0,conn)); %watershed_meyer requires MATLAB 2007a or higher
                                                        %as well as the image processing toolbox
clear cell

% Filter away background and bad regions
idx = W(seeds==max(seeds(:)));
clear seeds
regions = ismember(W, idx);

return
